5 Pop Culture Nail Decals & The Totally Appropriate Places to Wear Them | YouBeauty
Author: http://www.youbeauty.com/authors/leah-prinzivalli
Description: Five cool pop culture nail decals including Drake, Saved by the Bell, and Mean Girls.
Keywords: nail decals, pop culture nail decals, drake, saved by the bell, nail art
Date: 2014-12-17T07:07:23-08:00

#### Follow Us

Facebook Pinterest

We're email friends!

If you'd like deeper access (taking quizzes, leaving comments) please register here.

# 5 Pop Culture Nail Decals & The Totally Appropriate Places to Wear Them

## Ever wish you could carry Drake around with you?

By Leah Prinzivalli
| December 17th, 2014

| 0 Comments

0
SHARES
Share Pin Tweet Email

NailSpin

The joint elevation of fan culture and nail art has left us with something magical: Drake nail decals. It doesn’t stop there – you can now wear your favorite '90s TV characters and even movie quotes on your nails with pride. Although its a personal style game changer, it all costs less than $10.

Here are our top five picks and recommendations of totally appropriate places to wear them. But remember the Internet is a wonderland, so don’t stop until you find your own favorite pop culture moment:

Jane's Tiny Things/Forever 21

For your high school reunion...

"Saved by the Bell" nail decals at Forever 21, $9
Zack Morris, Kelly Kapowski and the gang reunite right here on your hands. The decals are printed in color and black and white, but if you’re a "Saved by the Bell" fan, you’re obviously choosing the neon.

fingerprintsdecals

For a movie marathon...

"Harry Potter" decals by fingerprintsdecals on Etsy, $5.50
Remember when Emma Watson wasn’t an international feminist and was instead a small wizard? The Etsy shop fingerprints has zapped her and her fellow Gryffindors until they’re small enough to fit on a pinky.

PaipurNails

For that one friend…

"Mean Girls" quotes by PaipurNails at Etsy, $4
Don’t we all know one person who has memorized every line from "Mean Girls"? For Etsy seller PaipurNails, she is that one person, and she has found her calling with decals that say “Burn Book” and “She doesn’t even go here.”

NailSpin

For a date...

"The Godfather" by NailSpin at Etsy, $5
What better way to show how cultured you are than adding Vito Corleone to your beauty routine? Your high school friends probably had a "Godfather" poster in their dorm rooms – one up them by putting him on your nails.

NailSpin

For the afterparty...

Drake by NailSpin at Etsy, $6

You can stick a Post-It to your desk that says “‘Live In the Moment” or you can wear YOLO nail decals. We all sometimes need a little daily inspiration – personally, I’d love to get it from Drake’s face on my ring finger.

Related Articles:

Flower Nail Art That Works for Every Season
3 Nail Art Designs That Last a Whole Month

NailSpin

The joint elevation of fan culture and nail art has left us with something magical: Drake nail decals. It doesn’t stop there – you can now wear your favorite '90s TV characters and even movie quotes on your nails with pride. Although its a personal style game changer, it all costs less than $10.

Here are our top five picks and recommendations of totally appropriate places to wear them. But remember the Internet is a wonderland, so don’t stop until you find your own favorite pop culture moment:

Jane's Tiny Things/Forever 21

For your high school reunion...

"Saved by the Bell" nail decals at Forever 21, $9
Zack Morris, Kelly Kapowski and the gang reunite right here on your hands. The decals are printed in color and black and white, but if you’re a "Saved by the Bell" fan, you’re obviously choosing the neon.

fingerprintsdecals

For a movie marathon...

"Harry Potter" decals by fingerprintsdecals on Etsy, $5.50
Remember when Emma Watson wasn’t an international feminist and was instead a small wizard? The Etsy shop fingerprints has zapped her and her fellow Gryffindors until they’re small enough to fit on a pinky.

PaipurNails

For that one friend…

"Mean Girls" quotes by PaipurNails at Etsy, $4
Don’t we all know one person who has memorized every line from "Mean Girls"? For Etsy seller PaipurNails, she is that one person, and she has found her calling with decals that say “Burn Book” and “She doesn’t even go here.”

NailSpin

For a date...

"The Godfather" by NailSpin at Etsy, $5
What better way to show how cultured you are than adding Vito Corleone to your beauty routine? Your high school friends probably had a "Godfather" poster in their dorm rooms – one up them by putting him on your nails.

NailSpin

For the afterparty...

Drake by NailSpin at Etsy, $6

You can stick a Post-It to your desk that says “‘Live In the Moment” or you can wear YOLO nail decals. We all sometimes need a little daily inspiration – personally, I’d love to get it from Drake’s face on my ring finger.

Related Articles:

Flower Nail Art That Works for Every Season
3 Nail Art Designs That Last a Whole Month

Share Pin Tweet Email
Tags: Mean Girls, Nail Decals, Nail Polish, Nails, Skin, Nail Art
Print
Save
Smart is sexy - get our newsletter:

Let's be friends!
Pinterest
Follow

#### Join the Conversation

Stories We Love

#### Comments on this Article (0) | Leave a Comment

Loading…

3. Reason*
4. Explanation

Sexual Satisfaction Quiz

#### How's Your Sex Life?

Great sex does more than blow your mind—it's good for your heart, your head and your beauty.

Take Quiz
Let's hang out
Pinterest
Follow

Most Popular

- ###### Should Women Receive Paid Menstrual Leave?

- ###### Why You Shouldn't Ignore Vitamin D, The "Sunshine Vitamin"

- ###### Alyssa Milano Asks Why Her Breastfeeding Selfie Got More Hate Than Kim’s Butt Pics

- ###### 8 Exercises to Get Rid of Back Fat

- ###### What Is Leaky Gut Syndrome?

X

###### Be Your Most Beautiful You

Highlight your eye color. Flaunt your body shape. Harness your confidence. Take our quizzes to better know yourself and get science-based, individualized advice to embrace your true beauty.

- ##### Sexual Satisfaction Quiz

  #### How's Your Sex Life?

  Great sex does more than blow your mind—it's good for your heart, your head and your beauty.

  Take Quiz

- #### Sleep Quality Quiz

  #### Do You Get Enough Quality Sleep?

  Good sleepers are beautiful, happier and enjoy better sex. Learn how to be better rested.

  Take Quiz

- #### Healthy Hair Quiz

  #### There Are 16 Factors That Determine Your Hair Type

  Learn why your hair does what it does, and get styling and product tips to make it do what you want.

  Take Quiz

- #### Eye Makeup Quiz

  #### Play Up Your Peepers

  If shopping for eye makeup is one big guessing game, find your best colors here.

  Take Quiz
- See all 33 quizzes

<< Close

## Sign In or Sign Up

### Join the YouBeauty community! Start discussions, share your advice and comment on stories. Save articles you love to your MyBeauty Dashboard for anytime access (you can track your discussions there, too). Plus, take any of our quizzes for personal beauty and wellness advice.

1. Email Address*

Do you have a YouBeauty password?

No, I am new to YouBeauty
Yes, my password is:

Forgot your password?

I sign in to YouBeauty by connecting my Facebook, Google Plus, Twitter, Yahoo, or AOL account.
CONTACT US

#### Need Advice?

Our experts and readers can help you—post your questions in YouTalk.

Do you have feedback, questions or concerns about YouBeauty? Send us an email using this form, or a letter at the below address.

YouBeauty.com
185 Madison Avenue
Floor 5
New York, NY 10016

* Fields marked with an asterisk are required

1. *I am writing to:*
2. *Email Address:*
3. *First Name:*
4. *Last Name:*
5. *Your Message:*
6. *What is 8 + 5*
Spell out the answer, for example 5 + 2 = seven